@@ -231,6 +231,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                 'domain,'
                 'provisionDate,'
                 'hardwareStatus,'
+                'bareMetalInstanceFlag,'
                 'processorPhysicalCoreAmount,'
                 'memoryCapacity,'
                 'notes,'
@@ -269,6 +270,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                 'hourlyBillingFlag,'
                 'tagReferences[id,tag[name,id]],'
                 'networkVlans[id,vlanNumber,networkSpace],'
+                'monitoringServiceComponent,networkMonitors[queryType,lastResult,responseAction],'
                 'remoteManagementAccounts[username,password]'
             )
 
@@ -834,6 +836,8 @@ class HardwareManager(utils.IdentifierMixin, object):
 
         :returns: bool
         """
+        result = None
+        maintenance_window_id = None
         upgrade_prices = self._get_upgrade_prices(instance_id)
         prices = []
         data = {}
@@ -849,14 +853,26 @@ class HardwareManager(utils.IdentifierMixin, object):
 
         server_response = self.get_instance(instance_id)
         package_id = server_response['billingItem']['package']['id']
+        location_id = server_response['datacenter']['id']
 
         maintenance_window = datetime.datetime.now(utils.UTC())
+        maintenance_window_detail = self.get_maintenance_windows_detail(location_id)
+        if maintenance_window_detail:
+            maintenance_window_id = maintenance_window_detail.get('id')
+
         order = {
             'complexType': 'SoftLayer_Container_Product_Order_Hardware_Server_Upgrade',
-            'properties': [{
-                'name': 'MAINTENANCE_WINDOW',
-                'value': maintenance_window.strftime("%Y-%m-%d %H:%M:%S%z")
-            }],
+            'properties': [
+                {
+                    'name': 'MAINTENANCE_WINDOW',
+                    'value': maintenance_window.strftime("%Y-%m-%d %H:%M:%S%z")
+                },
+                {
+                    'name': 'MAINTENANCE_WINDOW_ID',
+                    'value': str(maintenance_window_id)
+                }
+
+            ],
             'hardware': [{'id': int(instance_id)}],
             'packageId': package_id
         }
@@ -878,11 +894,30 @@ class HardwareManager(utils.IdentifierMixin, object):
 
         if prices:
             if test:
-                self.client['Product_Order'].verifyOrder(order)
+                result = self.client['Product_Order'].verifyOrder(order)
             else:
-                self.client['Product_Order'].placeOrder(order)
-            return True
-        return False
+                result = self.client['Product_Order'].placeOrder(order)
+        return result
+
+    def get_maintenance_windows_detail(self, location_id):
+        """Get the disks prices to be added or upgraded.
+
+        :param int location_id: Hardware Server location id.
+        :return int:
+        """
+        result = None
+        begin_date_object = datetime.datetime.now()
+        begin_date = begin_date_object.strftime("%Y-%m-%dT00:00:00.0000-06:00")
+        end_date_object = datetime.date.today() + datetime.timedelta(days=30)
+        end_date = end_date_object.strftime("%Y-%m-%dT00:00:00.0000-06:00")
+
+        result_windows = self.client['SoftLayer_Provisioning_Maintenance_Window'].getMaintenanceWindows(begin_date,
+                                                                                                        end_date,
+                                                                                                        location_id)
+        if len(result_windows) > 0:
+            result = result_windows[0]
+
+        return result
 
     @retry(logger=LOGGER)
     def get_instance(self, instance_id):
@@ -893,7 +928,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                   the specified instance.
         """
         mask = [
-            'billingItem[id,package[id,keyName],nextInvoiceChildren]'
+            'datacenter,billingItem[id,package[id,keyName],nextInvoiceChildren]'
         ]
         mask = "mask[%s]" % ','.join(mask)
 
@@ -1030,6 +1065,45 @@ class HardwareManager(utils.IdentifierMixin, object):
 
         return disk_price
 
+    def get_components(self, hardware_id, mask=None, filter_component=None):
+        """Get details about a hardware components.
+
+        :param int hardware_id: the instance ID
+        :returns: A dictionary containing a large amount of information about
+                  the specified components.
+        """
+        if not mask:
+            mask = 'id,hardwareComponentModel[longDescription,' \
+                   'hardwareGenericComponentModel[description,hardwareComponentType[keyName]],' \
+                   'firmwares[createDate,version]]'
+
+        if not filter_component:
+            filter_component = {"components": {
+                "hardwareComponentModel": {
+                    "firmwares": {
+                        "createDate": {
+                            "operation": "orderBy",
+                            "options": [
+                                {
+                                    "name": "sort",
+                                    "value": [
+                                        "DESC"
+                                    ]
+                                },
+                                {
+                                    "name": "sortOrder",
+                                    "value": [
+                                        1
+                                    ]}]}
+                    }}}}
+
+        return self.client.call('Hardware_Server', 'getComponents',
+                                mask=mask, filter=filter_component, id=hardware_id)
+
+    def get_sensors(self, hardware_id):
+        """Returns Hardware sensor data"""
+        return self.client.call('Hardware', 'getSensorData', id=hardware_id)
+
 
 def _get_bandwidth_key(items, hourly=True, no_public=False, location=None):
     """Picks a valid Bandwidth Item, returns the KeyName"""
