@@ -43,15 +43,20 @@ DEFAULT_VLAN_MASK = ','.join([
     'totalPrimaryIpAddressCount',
     'virtualGuestCount',
     'networkSpace',
+    'networkVlanFirewall[id,fullyQualifiedDomainName,primaryIpAddress]',
+    'attachedNetworkGateway[id,name,networkFirewall]',
 ])
 DEFAULT_GET_VLAN_MASK = ','.join([
     'firewallInterfaces',
     'primaryRouter[id, fullyQualifiedDomainName, datacenter]',
     'totalPrimaryIpAddressCount',
     'networkSpace',
+    'billingItem',
     'hardware',
     'subnets',
     'virtualGuests',
+    'networkVlanFirewall[id,fullyQualifiedDomainName,primaryIpAddress]',
+    'attachedNetworkGateway[id,name,networkFirewall]',
 ])
 
 
@@ -752,3 +757,70 @@ class NetworkManager(object):
         """
         result = self.client.call('SoftLayer_Network_Subnet_IpAddress', 'editObject', note, id=identifier)
         return result
+
+    def get_cancel_failure_reasons(self, identifier):
+        """get the reasons why we cannot cancel the VLAN.
+
+        :param integer identifier:  the instance ID
+        """
+        return self.vlan.getCancelFailureReasons(id=identifier)
+
+    def cancel_item(self, identifier, cancel_immediately,
+                    reason_cancel, customer_note):
+        """Cancel a billing item immediately, deleting all its data.
+
+        :param integer identifier: the instance ID to cancel
+        :param string reason_cancel: reason cancel
+        """
+        return self.client.call('SoftLayer_Billing_Item', 'cancelItem',
+                                True,
+                                cancel_immediately,
+                                reason_cancel,
+                                customer_note,
+                                id=identifier)
+
+    def get_pods(self, datacenter=None):
+        """Calls SoftLayer_Network_Pod::getAllObjects()
+
+        returns list of all network pods and their routers.
+        """
+        _filter = None
+
+        if datacenter:
+            _filter = {"datacenterName": {"operation": datacenter}}
+
+        return self.client.call('SoftLayer_Network_Pod', 'getAllObjects', filter=_filter)
+
+    def get_list_datacenter(self):
+        """Calls SoftLayer_Location::getDatacenters()
+
+        returns all datacenter locations.
+        """
+        return self.client.call('SoftLayer_Location_Datacenter', 'getDatacenters')
+
+    def get_routers(self, identifier):
+        """Calls SoftLayer_Location::getRouters()
+
+        returns all routers locations.
+        """
+        return self.client.call('SoftLayer_Location_Datacenter', 'getHardwareRouters', id=identifier)
+
+    def get_closed_pods(self):
+        """Calls SoftLayer_Network_Pod::getAllObjects()
+
+        returns list of all closing network pods.
+        """
+        closing_filter = {
+            'capabilities': {
+                'operation': 'in',
+                'options': [{'name': 'data', 'value': ['CLOSURE_ANNOUNCED']}]
+            },
+            'name': {
+                'operation': 'orderBy',
+                'options': [{'name': 'sort', 'value': ['DESC']}]
+            }
+        }
+
+        mask = """mask[name, datacenterLongName, frontendRouterId, capabilities, datacenterId, backendRouterId,
+                backendRouterName, frontendRouterName]"""
+        return self.client.call('SoftLayer_Network_Pod', 'getAllObjects', mask=mask, filter=closing_filter)
