@@ -245,13 +245,14 @@ class VSManager(utils.IdentifierMixin, object):
                 'userData,'
                 '''billingItem[id,nextInvoiceTotalRecurringAmount,
                                package[id,keyName],
-                               children[categoryCode,nextInvoiceTotalRecurringAmount],
+                               children[description,categoryCode,nextInvoiceTotalRecurringAmount],
                                orderItem[id,
                                          order.userRecord[username],
                                          preset.keyName]],'''
                 'tagReferences[id,tag[name,id]],'
                 'networkVlans[id,vlanNumber,networkSpace],'
                 'dedicatedHost.id,'
+                'monitoringServiceComponent,networkMonitors[queryType,lastResult,responseAction],'
                 'placementGroupId'
             )
 
