@@ -323,7 +323,7 @@ class VirtTests(testing.TestCase):
 
     def test_create_options_prices_location(self):
         result = self.run_command(['vs', 'create-options', '--prices', 'dal13',
-                                  '--vsi-type', 'TRANSIENT_CLOUD_SERVER'])
+                                   '--vsi-type', 'TRANSIENT_CLOUD_SERVER'])
         self.assert_no_fail(result)
 
     @mock.patch('SoftLayer.CLI.formatting.confirm')
@@ -345,19 +345,19 @@ class VirtTests(testing.TestCase):
                                            'getResourceRecords')
         getResourceRecords.return_value = []
         createAargs = ({
-            'type': 'a',
-            'host': 'vs-test1',
-            'domainId': 12345,  # from SoftLayer_Account::getDomains
-            'data': '172.16.240.2',
-            'ttl': 7200
-        },)
+                           'type': 'a',
+                           'host': 'vs-test1',
+                           'domainId': 12345,  # from SoftLayer_Account::getDomains
+                           'data': '172.16.240.2',
+                           'ttl': 7200
+                       },)
         createPTRargs = ({
-            'type': 'ptr',
-            'host': '2',
-            'domainId': 123456,
-            'data': 'vs-test1.test.sftlyr.ws',
-            'ttl': 7200
-        },)
+                             'type': 'ptr',
+                             'host': '2',
+                             'domainId': 123456,
+                             'data': 'vs-test1.test.sftlyr.ws',
+                             'ttl': 7200
+                         },)
 
         result = self.run_command(['vs', 'dns-sync', '100'])
 
@@ -400,12 +400,12 @@ class VirtTests(testing.TestCase):
             }
         }
         createV6args = ({
-            'type': 'aaaa',
-            'host': 'vs-test1',
-            'domainId': 12345,
-            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
-            'ttl': 7200
-        },)
+                            'type': 'aaaa',
+                            'host': 'vs-test1',
+                            'domainId': 12345,
+                            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
+                            'ttl': 7200
+                        },)
         guest.return_value = test_guest
         result = self.run_command(['vs', 'dns-sync', '--aaaa-record', '100'])
         self.assert_no_fail(result)
@@ -736,6 +736,13 @@ class VirtTests(testing.TestCase):
 
         self.assert_no_fail(result)
 
+    def test_usage_vs_cpu_lower_case(self):
+        result = self.run_command(
+            ['vs', 'usage', '100', '--start_date=2019-3-4', '--end_date=2019-4-2', '--valid_type=cpu0',
+             '--summary_period=300'])
+
+        self.assert_no_fail(result)
+
     def test_usage_vs_memory(self):
         result = self.run_command(
             ['vs', 'usage', '100', '--start_date=2019-3-4', '--end_date=2019-4-2', '--valid_type=MEMORY_USAGE',
@@ -754,6 +761,7 @@ class VirtTests(testing.TestCase):
         self.assertIsInstance(result.exception, exceptions.CLIAbort)
 
     def test_bandwidth_vs(self):
+        self.skipTest("Skipping until VIRT-11733 is released")
         if sys.version_info < (3, 6):
             self.skipTest("Test requires python 3.6+")
 
@@ -782,6 +790,7 @@ class VirtTests(testing.TestCase):
         self.assertEqual(output_list[0]['Pub In'], 1.3503)
 
     def test_bandwidth_vs_quite(self):
+        self.skipTest("Skipping until VIRT-11733 is released")
         result = self.run_command(['vs', 'bandwidth', '100', '--start_date=2019-01-01', '--end_date=2019-02-01', '-q'])
         self.assert_no_fail(result)
 
@@ -813,11 +822,11 @@ class VirtTests(testing.TestCase):
             'Recurring Fee': None,
             'Total': 1.54,
             'prices': [
-                {'Recurring Price': 1},
-                {'Recurring Price': 1},
-                {'Recurring Price': 1},
-                {'Recurring Price': 1},
-                {'Recurring Price': 1}
+                {'Description': '1 GB', 'Recurring Price': 1},
+                {'Description': 'Reboot / Remote Console', 'Recurring Price': 1},
+                {'Description': '1 Gbps Public & Private Network Uplinks', 'Recurring Price': 1},
+                {'Description': '1 Gbps Public Uplink', 'Recurring Price': 1},
+                {'Description': '1 Gbps Private Uplink', 'Recurring Price': 1}
             ]
         }
         self.assert_no_fail(result)
@@ -928,3 +937,7 @@ class VirtTests(testing.TestCase):
         result = self.run_command(['vs', 'authorize-storage', '--username-storage=SL01SEL301234-11',
                                    '--portable-id=12345', '1234'])
         self.assert_no_fail(result)
+
+    def test_monitoring_vs(self):
+        result = self.run_command(['vs', 'monitoring', '1234'])
+        self.assert_no_fail(result)
